==> crm-page-3.5.4.release-classes.jar: META-INF/resources/resources/js/choseSelect.js <==

var onblurFlag = false;

function onblurInput(event) {
    if(onblurFlag){
        var that = event.currentTarget;
        $(that).val("");
    }
    setTimeout(function () {
        $(that).closest('.inputComponent').siblings('.selectList').hide();
    },500)

}

// 聚焦
function focusInput(event){
    var that = event.currentTarget;
    $(that).closest('.inputComponent').siblings('.selectList').show();
}

// 输入
function keyopInput(event){
    var that = event.currentTarget;
    var value = $(that).val();

    var tableType = "act_quota";
    var categoriesCode = $("#categoriesCode").val();
    var budgetCode = $("#budgetCode").val();
    var paramObj = {
        list: [], // 接口返回的数据
        nameList: ['fineName'],  //option上所要显示的数据字段
        valList: [{'key':'fineCode','id':'actSubclassCode'}], // 其他表单所需要的数据,key为表单展示的值,id为所需展示的表单的id
        hideList: ['fineCode'], // 需要隐藏显示的数据字段
    }
    // $.ajax({
    //     type: "POST",
    //     url: '/budget/ttApiFineController/getActFineList?categoriesStatus=009&tableType=act_quota&categoriesCode='+categoriesCode+'&budgetCode='+budgetCode,
    //     async: true,
    //     data: {'fineName':value},
    //     success: function(msg){
    //         paramObj.list = msg;
    //         ajaxInput($(that),paramObj);
    //     }
    // });
}

// 选择
function chooseOption(event){
    var that = event.currentTarget;
    var inputVal = $(that).closest('.selectList').siblings('.inputComponent').find('.input');
    inputVal.val($(that).text());
    $(that).closest('.selectList').hide();
    var valList = JSON.parse($(that).attr('data-valList'));
    if(valList && valList.length){
        for(var k = 0; k < valList.length; k ++){
            var value = $(that).attr('data-' + valList[k].key);
            $('#' + valList[k].id).val(value);
        }
    }
}


// 展示弹窗
function showDialog(elem){
    $(elem).show();
}

// 接口数据处理
function ajaxInput(that,paramObj){
    var selectList = that.closest('.inputComponent').siblings('.selectList');
    selectList.empty();
    if(paramObj.list && paramObj.list.length){
        for(var i = 0; i < paramObj.list.length; i ++){
            var nameTem = '';
            var optionData = '';
            var listData = '';
            if(paramObj.nameList && paramObj.nameList.length){
                for(var j = 0; j < paramObj.nameList.length; j ++){
                    nameTem += paramObj.list[i][paramObj.nameList[j]] + ' ';
                }
            }
            if(paramObj.hideList && paramObj.hideList.length){
                for(var a = 0; a < paramObj.hideList.length; a ++){
                    optionData += 'data-' + paramObj.hideList[a] + '=' + paramObj.list[i][paramObj.hideList[a]] + ' ';
                }
            }
            if(paramObj.valList && paramObj.valList.length){
                for(var k = 0; k < paramObj.valList.length; k ++){
                    var keyName = paramObj.valList[k].key
                    listData += 'data-' + keyName + '=' + paramObj.list[i][keyName] + ' ';
                }
            }
            selectList.append("<div class='selectItem'  onclick='chooseOption(event)' data-valList=" + JSON.stringify(paramObj.valList) + ' ' + listData + " " + optionData +">" + nameTem + "</div>");
        }
    }else{
        onblurFlag = true;
    }
}

==> crm-page-3.8.7.release-classes.jar: META-INF/resources/resources/js/choseSelect.js <==

var onblurFlag = false;

function onblurInput(event) {
    var that = event.currentTarget;
    if(onblurFlag){
        $(that).val("");
    }
    var selectList =  $(that).closest('.inputComponent').siblings('.selectList');
    setTimeout(function () {
        selectList.empty();
    },300)

}

// 聚焦
function focusInput(event){
    var that = event.currentTarget;
    $(that).closest('.inputComponent').siblings('.selectList').show();
}

// 输入
function keyopInput(event){
    var that = event.currentTarget;
    var value = $(that).val();

    var tableType = "act_quota";
    var categoriesCode = $("#categoriesCode").val();
    var budgetCode = $("#budgetCode").val();
    var paramObj = {
        list: [], // 接口返回的数据
        nameList: ['fineName'],  //option上所要显示的数据字段
        valList: [{'key':'fineCode','id':'actSubclassCode'}], // 其他表单所需要的数据,key为表单展示的值,id为所需展示的表单的id
        hideList: ['fineCode'], // 需要隐藏显示的数据字段
    }
    // $.ajax({
    //     type: "POST",
    //     url: '/budget/ttApiFineController/getActFineList?categoriesStatus=009&tableType=act_quota&categoriesCode='+categoriesCode+'&budgetCode='+budgetCode,
    //     async: true,
    //     data: {'fineName':value},
    //     success: function(msg){
    //         paramObj.list = msg;
    //         ajaxInput($(that),paramObj);
    //     }
    // });
}

// 选择
function chooseOption(event){
    var that = event.currentTarget;
    var inputVal = $(that).closest('.selectList').siblings('.inputComponent').find('.input');
    inputVal.val($(that).text());
    $(that).closest('.selectList').hide();
    var valList = JSON.parse($(that).attr('data-valList'));
    if(valList && valList.length){
        for(var k = 0; k < valList.length; k ++){
            var value = $(that).attr('data-' + valList[k].key);
            $('#' + valList[k].id).val(value);
        }
    }
}


// 展示弹窗
function showDialog(elem){
    $(elem).show();
}

// 接口数据处理
function ajaxInput(that,paramObj){
    onblurFlag = true;
    var selectList = that.closest('.inputComponent').siblings('.selectList');
    selectList.empty();
    if(paramObj.list && paramObj.list.length){
        for(var i = 0; i < paramObj.list.length; i ++){
            var nameTem = '';
            var optionData = '';
            var listData = '';
            if(paramObj.nameList && paramObj.nameList.length){
                for(var j = 0; j < paramObj.nameList.length; j ++){
                    nameTem += paramObj.list[i][paramObj.nameList[j]] + ' ';
                }
            }
            if(paramObj.hideList && paramObj.hideList.length){
                for(var a = 0; a < paramObj.hideList.length; a ++){
                    optionData += 'data-' + paramObj.hideList[a] + '=' + paramObj.list[i][paramObj.hideList[a]] + ' ';
                }
            }
            if(paramObj.valList && paramObj.valList.length){
                for(var k = 0; k < paramObj.valList.length; k ++){
                    var keyName = paramObj.valList[k].key
                    listData += 'data-' + keyName + '=' + paramObj.list[i][keyName] + ' ';
                }
            }
            selectList.append("<div class='selectItem'  onclick='chooseOption(event)' data-valList=" + JSON.stringify(paramObj.valList) + ' ' + listData + " " + optionData +">" + nameTem + "</div>");
        }
    }
}
